import argparse
import os
from typing import List

from tqdm.auto import tqdm

from .parse_job_page import get_job_description
from .parse_main_page import get_table_from_aas

FILENAME = "aas_jobs.csv"


class style:
    RED = "\033[31m"
    GREEN = "\033[32m"
    RESET = "\033[0m"


def save_table(with_descriptions=False):
    if os.path.exists(FILENAME):
        print(
            style.RED + f"{FILENAME} exists, not overwritting." + style.RESET
        )
    else:
        table = get_table_from_aas()
        if with_descriptions:
            table["Description"] = get_descriptions(table.Link)
        table.to_csv(FILENAME, index=False)
        print(style.GREEN + f"{FILENAME} saved" + style.RESET)
        print("Happy job hunting \U0000263A")


def get_descriptions(links: List[str]):
    return [
        get_job_description(l)
        for l in tqdm(links, desc="Getting job descriptions")
    ]


def get_cli_args():
    parser = argparse.ArgumentParser(
        prog="download_aas_jobs",
        description=f"Downloads the job table from https://jobregister.aas.org/ and saves it in {FILENAME}",
    )
    parser.add_argument(
        "-v",
        action="store_true",
        help="If the job descriptions should also be stored (False by default)",
    )
    args = parser.parse_args()
    return args.v


def main():
    with_descriptions = get_cli_args()
    save_table(with_descriptions)



import unittest
from aas_job_register_downloader.parse_main_page import get_table_from_aas
import os

CLEAN_AFTER = True


class TestMainPageParser(unittest.TestCase):
    def setUp(self) -> None:
        self.outdir = "out_test"
        os.makedirs(self.outdir, exist_ok=True)

    def tearDown(self) -> None:
        if CLEAN_AFTER:
            import shutil

            shutil.rmtree(self.outdir)

    def test_table_generation(self):
        table = get_table_from_aas()
        table.to_csv(f"{self.outdir}/aas_table.csv")


if __name__ == "__main__":
    unittest.main()



# -*- coding: utf-8 -*-

__all__ = []

__author__ = "Avi Vajpeyi"
__email__ = "avi.vajpeyi@gmail.com"
__uri__ = "https://github.com/avivajpeyi/aas_job_register_downloader"
__license__ = "MIT"
__description__ = "All the TESS exoplanets!"
__copyright__ = "Copyright 2021 AJRD developers"
__contributors__ = "https://github.com/avivajpeyi/aas_job_register_downloader/graphs/contributors"



import unittest
from aas_job_register_downloader.parse_main_page import get_table_from_aas
from aas_job_register_downloader.parse_job_page import get_job_description


class TestJobPageParser(unittest.TestCase):
    def test_job_description_getter(self):
        table = get_table_from_aas()
        job_url = table["Link"].iloc[0]
        description = get_job_description(job_url)
        self.assertIsInstance(description, str)


if __name__ == "__main__":
    unittest.main()



from http import HTTPStatus

import numpy as np
import pandas as pd
import requests
from bs4 import BeautifulSoup
from bs4.element import Tag


def download_page(url) -> BeautifulSoup:
    resp = requests.get(url)
    if resp.status_code == HTTPStatus.OK:
        return BeautifulSoup(resp.text, "html.parser")
    raise requests.HTTPError(resp)


class Table(pd.DataFrame):
    @classmethod
    def from_bs4(cls, table_html: Tag, link_base=""):
        rows = table_html.find_all("tr")
        header = list(rows.pop(0).stripped_strings)
        contents = [list(row.stripped_strings) for row in rows]
        contents = np.array(contents).T.tolist()
        if link_base != "":
            links = [
                f"{link_base}{a.get('href')}" for a in table_html.find_all("a")
            ]
            header.append("Link")
            contents.append(links)
        data = {header[i]: contents[i] for i in range(len(header))}
        return cls(data)



from typing import Dict, List

import pandas as pd
from bs4 import BeautifulSoup

from .html_parser import Table, download_page

MAIN = "https://jobregister.aas.org"

JOB_IDS = [
    "FacPosNonTen",
    "FacPosTen",
    "PostDocFellow",
    "PreDocGrad",
    "SciEng",
    "SciMgmt",
    "SciTechStaff",
    "Other",
]


def get_job_types(page: BeautifulSoup) -> Dict[str, str]:
    return {
        tag["id"]: tag.get_text()
        for tag in page.find_all(id=True)
        if tag["id"] in JOB_IDS
    }


def get_tables_from_aas():
    page = download_page(MAIN)
    job_types = get_job_types(page)
    tables = get_tables(page)
    tables_dict = {}
    for (job_id, job_type), table in zip(job_types.items(), tables):
        table["Job Type"] = job_type
        tables_dict[job_id] = table
    return tables_dict


def get_table_from_aas():
    tables_dict = get_tables_from_aas()
    return pd.concat([t for t in tables_dict.values()])


def get_tables(page: BeautifulSoup) -> List[Table]:
    html_tables = page.find_all("table")
    return [Table.from_bs4(t, link_base=MAIN) for t in html_tables]



from .html_parser import download_page


def get_job_description(job_url) -> str:
    page = download_page(job_url)
    description_html = page.find_all("p")
    description = [line.get_text() for line in description_html]
    return "\n".join(description)



import unittest
from aas_job_register_downloader.cli import main
import pytest
import os
from unittest.mock import patch
import sys

CLEAN_AFTER = True


class TestCli(unittest.TestCase):
    def setUp(self) -> None:
        self.outdir = "out_test"
        self.cwd = os.getcwd()
        os.makedirs(self.outdir, exist_ok=True)
        os.chdir(self.outdir)

    def tearDown(self) -> None:
        os.chdir(self.cwd)
        if CLEAN_AFTER:
            import shutil

            shutil.rmtree(self.outdir)

    @pytest.mark.slow
    def test_with_descriptions(self):
        testargs = ["command", "-v"]
        with patch.object(sys, "argv", testargs):
            main()

    def test_without_descriptions(self):
        testargs = ["command"]
        with patch.object(sys, "argv", testargs):
            main()


if __name__ == "__main__":
    unittest.main()



#!/usr/bin/env python

# Inspired by:
# https://hynek.me/articles/sharing-your-labor-of-love-pypi-quick-and-dirty/

import codecs
import os
import re

from setuptools import find_packages, setup

# PROJECT SPECIFIC

NAME = "aas_job_register_downloader"
PACKAGES = find_packages(where="src")
META_PATH = os.path.join("src", "aas_job_register_downloader", "__init__.py")
CLASSIFIERS = [
    "Development Status :: 5 - Production/Stable",
    "Intended Audience :: Developers",
    "Intended Audience :: Science/Research",
    "License :: OSI Approved :: MIT License",
    "Operating System :: OS Independent",
    "Programming Language :: Python",
    "Programming Language :: Python :: 3",
]
INSTALL_REQUIRES = ["beautifulsoup4", "pandas", "requests"]
EXTRA_REQUIRE = {"test": ["pytest>=3.6"]}
EXTRA_REQUIRE["dev"] = EXTRA_REQUIRE["test"] + [
    "pre-commit",
    "flake8",
    "black",
    "isort",
]

# END PROJECT SPECIFIC


HERE = os.path.dirname(os.path.realpath(__file__))


def read(*parts):
    with codecs.open(os.path.join(HERE, *parts), "rb", "utf-8") as f:
        return f.read()


def find_meta(meta, meta_file=read(META_PATH)):
    meta_match = re.search(
        r"^__{meta}__ = ['\"]([^'\"]*)['\"]".format(meta=meta), meta_file, re.M
    )
    if meta_match:
        return meta_match.group(1)
    raise RuntimeError("Unable to find __{meta}__ string.".format(meta=meta))


if __name__ == "__main__":
    setup(
        name=NAME,
        version="1.0",
        author=find_meta("author"),
        author_email=find_meta("email"),
        maintainer=find_meta("author"),
        maintainer_email=find_meta("email"),
        url=find_meta("uri"),
        license=find_meta("license"),
        description=find_meta("description"),
        long_description=read("README.md"),
        long_description_content_type="text/markdown",
        packages=PACKAGES,
        package_dir={"": "src"},
        include_package_data=True,
        install_requires=INSTALL_REQUIRES,
        extras_require=EXTRA_REQUIRE,
        classifiers=CLASSIFIERS,
        zip_safe=True,
        entry_points={
            "console_scripts": [
                "download_aas_jobs=aas_job_register_downloader.cli:main"
            ]
        },
    )
